#
# spec file for package sil-doulos-fonts
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define fontname Doulos

Name:           sil-doulos-fonts
# Provides:       locale(vi)
Version:        6.101
Release:        1.4
Summary:        Doulos SIL Fonts Similar to Times
License:        OFL-1.1
Group:          System/X11/Fonts
URL:            https://software.sil.org/doulos
Source0:        https://software.sil.org/downloads/r/doulos/DoulosSIL-%{version}.zip
BuildRequires:  fontpackages-devel
BuildRequires:  unzip
%reconfigure_fonts_prereq
Obsoletes:      sil-doulos < %{version}
Provides:       sil-doulos = %{version}
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch

%description
Doulos SIL provides glyphs for a wide range of Latin and Cyrillic
characters. Doulos's design is similar to the design of the Times-like
fonts, but only has a single regular face. It is intended for use alongside
other Times-like fonts where a range of styles (italic, bold) are not
needed.

%prep
%setup -q -n %{fontname}SIL-%{version}
chmod 644 *.txt *.ttf
# Remove DOS line endings:
for i in *.txt; do
 sed -i 's/.$//' $i
done

%build

%install
mkdir -p %{buildroot}%{_ttfontsdir}/
install -c -m 644 *.ttf %{buildroot}%{_ttfontsdir}

%reconfigure_fonts_scriptlets

%files
%license OFL*.txt
%doc README.txt documentation/pdf/*.pdf
%{_ttfontsdir}

%changelog
* Tue May 17 2022 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 6.101
  * The font now supports SIL TypeTuner
  * New locl OpenType feature that supports Macedonian Cyrillic alternates
  * Serbian and Macedonian alternates are also available through
    a new OpenType feature (cv84) for applications that do not support
    language-specific locl features
  * Characters have been added to support Unicode versions up to 14.0.0
  * The special-purpose modified fonts have been updated to be based on
    the current version.
- Update to version 6.001
  * Reverted font Postscript name to that used in v5 and earlier to
    avoid problems with unrecognized fonts when opening older documents
- Update to version 6.000
  * Removed DSIGs added in version 5.000. These have now been removed to
    reflect current best practice font development guidance.
  * Graphite has been removed. Application and OS support for OpenType
    has greatly improved, so the need for Graphite in this font is greatly reduced.
  * Removed the “Show Invisibles” feature.
  * Removed support for nine-level pitch contours.
    These will be replaced by a standalone pitch contours font in the future.
  * Characters added to support Unicode versions 7.0-13.0,
    including feature support (e.g. small caps)
  * First release that uses a UFO-based design and production workflow
  * Feature to support side-by-side rendering of U+0300 plus U+0301
  * Tone letter features (cv91 & cv92) now supported through OpenType
  * Width of typographic spaces have been made more consistent to reflect
  * Fixed some small capital correspondences, including added support for clicks
  * Fixed problems with spacing of tone letters
  * Fixes and improvements to various glyphs
* Wed Mar 25 2015 p.drouand@gmail.com
- Update to version 5.000
  * Added Stylistic Sets to the font for OpenType support of
    previously Graphite-only features
  * Added Character Variants to the font for OpenType support of
    previously Graphite-only features
  * Added Serbian feature when Serbian language is turned on
  * Added hook D variant feature (for U+018A/U+0257)
  * Removed "Show deprecated PUA" feature
  * Removed “Romanian-style diacritics” feature (because glyphs are
    now encoded)
  * Removed “Diacritic selection” feature
  * Added U+039E, U+03BC, U+03C6 and U+03C9 in the Greek and Coptic block
  * Added U+0528..U+052F in the Cyrillic Supplement block
  * Added U+2041 in the General Punctuation block
  * Added U+2095..U+209C in the Superscripts and Subscripts block
  * Added U+20B6..U+20BD in the Currency Symbols block
  * Added U+210C, U+2113, U+2117, U+212D, U+2135, U+214F in the
    Letterlike Symbols block
  * Added U+2150..U+2152 and U+2189 in the Number Forms block
  * Added U+2226, U+2234..U+2235, U+2262, U+2282..U+2287 in the
    Mathematical Operators block
  * Added U+2640, U+2642, U+266D, U+266F in the Miscellaneous
    Symbols block
  * Added U+27E8..U+27E9 in the Miscellaneous Mathematical
    Symbols-A block
  * Added U+2C7E..U+2C7F in the Latin Extended-C block
  * Added U+2C88 in the Coptic block
  * Added U+2E00..U+2E0D, U+2E3A..U+2E3B in the Supplemental Punctuation block
  * Added U+A736..U+A73F, U+A742..U+A74D, U+A750..U+A787, U+A790..U+A7AD,
    U+A7B0..U+A7B1, U+A7F7..U+A7FA in the Latin Extended-D block. These
    were also added to relevant features.
  * Added U+A92E in the Kayah Li block (to support the Kayah Li language
    when using the Roman script)
  * Added U+AB64..U+AB65 in the Latin Extended-E block
  * Added U+1D40C, U+1D504..U+1D505, U+1D50A, U+1D50E..U+1D50F, U+1D514,
    U+1D516..U+1D517, U+1D519 in the Mathematical Alphanumeric Symbols block
  * Added PUA characters U+F26C (curl J) and U+F26D (left-hook b)
  * Characters in our PUA that were added to Unicode have had their codepoints
    updated: F1AD>A7F9, F266>A78E, F26B>A78D, F32C>0526, F32D>0527,
    F17B>1DFD, F209>2C70
  * These PUA characters were deprecated (now white on black glyphs): U+F17B,
    U+F1AD, U+F209, U+F247, U+F248, U+F266, U+F26B, U+F32C, U+F32D
  * Deleted U+0149 as it is officially deprecated in Unicode
  * Added support for shorter macrons under narrow letters (i,l,r,t). (This
    only works for Graphite or using precomposed characters in OpenType.)
  * Made it possible for saltillo characters (U+A78B and U+A78C) to "carry" diacritics
  * Improved design of U+A722..U+A725 and U+A78D
  * Refactored all cedilla positioning
  * Removal of unneeded duplicate glyphs (because of improvements in smart font code)
  * Bug fix in Graphite code to allow for simultaneous selection of
    Vietnamese alternates and Small Caps
  * Bug fix in Graphite code to allow for simultaneous selection of
    Ogonek alternates and Small Caps
  * "Hide tone contour staves" feature now works with single tonebar
  * Allowed combining marks to render properly with U+02D0
  * Changed postscript names for U+0218 and U+0219
  * Changed postscript names for U+2203, U+232A and U+2329
  * Optimized Graphite code for faster processing of plain ASCII text
  * Subscript and Superscript parentheses, minus, plus and equals were
    raised. Metrics were not changed.
  * Adjusted tails on U+2C6B, U+2C6C
  * Arrowhead design of U+21A8 modified to match the other arrows
  * Placement of Ogonek revisited
  * Changed the strongly curved hooks on Cyrillic U+04C3..U+04C4,
    U+04C7..U+04C8, U+04FC..U+04FD, U+0512..U+0513 to be more consistent
    with other hooks
  * Modified design of U+A78D to be more curved and less squared
- Update Url
* Wed Jul  4 2012 pgajdos@suse.cz
- amend spec file to reflect new font packaging scheme
  (see openFATE#313536);
* Thu May 17 2012 pgajdos@suse.com
- call spec-cleaner
* Fri Apr 27 2012 pgajdos@suse.com
- obsoletes and provides sil-doulos
* Wed Jan  4 2012 toms@suse.de
- Initial release 4.110
